import subprocess

class Node:

    def __init__(self, ip_address: str, reputation: float=0.0) -> None:
        self.ip_address = ip_address
        self.reputation = reputation

    def get_reputation(self, ip_address, count=3) -> float:
        # Costruisci il comando di ping
        command = ['ping', '-c', str(count), ip_address]
        counter = 0
        reputation = 1.0

        try:
            # Esegui il comando e cattura l'output riga per riga
            process = subprocess.Popen(command, stdout=subprocess.PIPE, stderr=subprocess.PIPE, text=True)
            for line in process.stdout:
                counter +=1
                # print(f"{counter}: {line.strip()}")
                if counter == 7:
                    elements = line.strip().split(",")
                    value = elements[2].strip().split(" ")[0]
                    value = float(value[:-1])
                    reputation = 100 if value == 0.0 else 10

            # Attendere che il processo termini
            process.wait()

            # Verifica se ci sono errori nel processo
            # if process.returncode != 0:
            #     print(f"Errore durante il ping. Codice di ritorno: {process.returncode}")
        except subprocess.CalledProcessError as e:
            # Se c'è un errore, stampa l'errore
            print(f"Errore durante il ping: {e}")
            reputation = -10.0
        
        return reputation

        


from setuptools import setup, find_packages

setup(
    name='cs_p2p',
    version='0.1.1.32',
    packages=find_packages(include=['cs_p2p', 'cs_p2p.*']),
    install_requires=[
        "loguru",
        "python-dotenv",
        "pyzmq",
    ],
    author='Enrico Zanardo',
    author_email='enrico.zanardo101@gmail.com',
    description='P2P library',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url='https://github.com/enricozanardo/cs_p2p.git',
    license='AGPLv3',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU Affero General Public License v3 or later (AGPLv3+)',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
    ],
)
